==> specberus-11.1.4.tgz: package/test/samples.js <==
export const samples = [
    {
        file: '2021-fpwd',
        profile: 'FPWD',
        title: 'Foo Time',
        docDate: '2021-11-4',
        editorIDs: [3439],
        editorNames: ['George Herald'],
        informative: false,
        process: 'https://www.w3.org/2023/Process-20231103/',
        delivererIDs: [45211],
        patentPolicy: 'https://www.w3.org/Consortium/Patent-Policy-20200915/',
        charters: ['https://www.w3.org/2021/02/webperf.html'],
        thisVersion: 'https://www.w3.org/TR/2021/WD-hr-foo-time-2-20211104/',
        latestVersion: 'https://www.w3.org/TR/hr-foo-time-2/',
        history: 'https://www.w3.org/standards/history/hr-foo-time-2',
        rectrack: 'Recommendation',
        editorsDraft: 'https://w3c.github.io/hr-foo-time/',
        updated: false,
    },
    {
        file: '2021-wd',
        profile: 'WD',
        title: 'Foo Time',
        docDate: '2021-11-4',
        editorIDs: [3439],
        editorNames: ['George Herald'],
        informative: false,
        process: 'https://www.w3.org/2023/Process-20231103/',
        delivererIDs: [45211],
        thisVersion: 'https://www.w3.org/TR/2021/WD-hr-time-2-20211104/',
        latestVersion: 'https://www.w3.org/TR/hr-time-2/',
        history: 'https://www.w3.org/standards/history/hr-time-2',
        rectrack: 'Recommendation',
        editorsDraft: 'https://w3c.github.io/hr-time/',
        updated: false,
        charters: ['https://www.w3.org/2021/02/webperf.html'],
        patentPolicy: 'https://www.w3.org/Consortium/Patent-Policy-20200915/',
    },
    {
        file: '2021-wd-shortname-change',
        profile: 'WD',
        rectrack: 'Recommendation',
        title: 'Foo Time',
        docDate: '2021-11-4',
        editorIDs: [3439],
        editorNames: ['George Herald'],
        informative: false,
        process: 'https://www.w3.org/2023/Process-20231103/',
        delivererIDs: [45211],
        thisVersion: 'https://www.w3.org/TR/2021/WD-new-name-3-20211104/',
        latestVersion: 'https://www.w3.org/TR/new-name-3/',
        history: 'https://www.w3.org/standards/history/new-name-3',
        editorsDraft: 'https://w3c.github.io/foo-time/',
        sameWorkAs: 'https://www.w3.org/TR/hr-time-3/',
        updated: false,
        patentPolicy: 'https://www.w3.org/Consortium/Patent-Policy-20200915/',
        charters: ['https://www.w3.org/2021/02/webperf.html'],
    },
    {
        file: '2021-cr',
        profile: 'CR',
        implementationFeedbackDue: '2022-6-6',
        implementationReport: 'https://wpt.fyi/hr-time/',
        title: 'High Resolution Time',
        docDate: '2021-11-4',
        editorIDs: [3439],
        editorNames: ['George Herald'],
        informative: false,
        process: 'https://www.w3.org/2023/Process-20231103/',
        delivererIDs: [45211],
        patentPolicy: 'https://www.w3.org/Consortium/Patent-Policy-20200915/',
        charters: ['https://www.w3.org/2021/02/webperf.html'],
        thisVersion: 'https://www.w3.org/TR/2021/CR-hr-time-2-20211104/',
        latestVersion: 'https://www.w3.org/TR/hr-time-2/',
        history: 'https://www.w3.org/standards/history/hr-time-2',
        rectrack: 'Recommendation',
        editorsDraft: 'https://w3c.github.io/hr-time/',
        updated: false,
    },
    {
        file: '2021-crd',
        profile: 'CRD',
        implementationReport: 'https://wpt.fyi/hr-time/',
        title: 'High Resolution Time',
        docDate: '2021-11-4',
        editorIDs: [3439],
        editorNames: ['George Herald'],
        informative: false,
        process: 'https://www.w3.org/2023/Process-20231103/',
        delivererIDs: [45211],
        charters: ['https://www.w3.org/2021/02/webperf.html'],
        patentPolicy: 'https://www.w3.org/Consortium/Patent-Policy-20200915/',
        thisVersion: 'https://www.w3.org/TR/2021/CRD-hr-time-2-20211104/',
        latestVersion: 'https://www.w3.org/TR/hr-time-2/',
        history: 'https://www.w3.org/standards/history/hr-time-2',
        rectrack: 'Recommendation',
        editorsDraft: 'https://w3c.github.io/hr-time/',
        updated: false,
    },
    {
        file: '2021-pr',
        profile: 'PR',
        prReviewsDue: '2022-7-13',
        implementationReport: 'https://wpt.fyi/hr-time/',
        title: 'High Resolution Time',
        docDate: '2021-11-4',
        editorIDs: [3439],
        editorNames: ['George Herald'],
        informative: false,
        process: 'https://www.w3.org/2023/Process-20231103/',
        delivererIDs: [45211],
        charters: ['https://www.w3.org/2021/02/webperf.html'],
        patentPolicy: 'https://www.w3.org/Consortium/Patent-Policy-20200915/',
        thisVersion: 'https://www.w3.org/TR/2021/PR-hr-time-2-20211104/',
        latestVersion: 'https://www.w3.org/TR/hr-time-2/',
        history: 'https://www.w3.org/standards/history/hr-time-2',
        rectrack: 'Recommendation',
        editorsDraft: 'https://w3c.github.io/hr-time/',
        updated: false,
    },
    {
        file: '2021-rec',
        profile: 'REC',
        title: 'CSS Color Module Level 3',
        docDate: '2022-1-18',
        editorIDs: [1464, 1438, 15393],
        editorNames: [
            'Tantek Çelik\n          (Mozilla Corporation,\n     and before at Microsoft\n     Corporation) <tantek@cs.stanford.edu>',
            'Chris Lilley',
            'L.\n      David Baron',
        ],
        informative: false,
        process: 'https://www.w3.org/2023/Process-20231103/',
        delivererIDs: [32061],
        charters: ['https://www.w3.org/2020/12/css-wg-charter.html'],
        patentPolicy: 'https://www.w3.org/Consortium/Patent-Policy-20200915/',
        thisVersion: 'https://www.w3.org/TR/2022/REC-css-color-3-20220118/',
        latestVersion: 'https://www.w3.org/TR/css-color-3/',
        history: 'https://www.w3.org/standards/history/css-color-3',
        rectrack: 'Recommendation',
        editorsDraft: 'https://drafts.csswg.org/css-color-3/',
        updated: false,
    },
    {
        file: '2021-dnote',
        profile: 'DNOTE',
        title: 'Ready-made Counter Styles',
        docDate: '2021-11-4',
        editorIDs: [3439],
        editorNames: ['Richard Ishida'],
        informative: false,
        process: 'https://www.w3.org/2023/Process-20231103/',
        delivererIDs: [32113],
        patentPolicy: 'https://www.w3.org/Consortium/Patent-Policy-20170801/',
        charters: [
            'https://www.w3.org/International/groups/wg/charter-2019-2021.html',
        ],
        thisVersion:
            'https://www.w3.org/TR/2021/DNOTE-predefined-counter-styles-20211104/',
        latestVersion: 'https://www.w3.org/TR/predefined-counter-styles/',
        history:
            'https://www.w3.org/standards/history/predefined-counter-styles',
        rectrack: 'Note',
        editorsDraft: 'https://w3c.github.io/predefined-counter-styles/',
        updated: false,
    },
    {
        file: '2021-note',
        profile: 'NOTE',
        title: 'Ready-made Counter Styles',
        docDate: '2021-11-4',
        editorIDs: [3439],
        editorNames: ['Richard Ishida'],
        informative: true,
        process: 'https://www.w3.org/2023/Process-20231103/',
        delivererIDs: [32113],
        patentPolicy: 'https://www.w3.org/Consortium/Patent-Policy-20170801/',
        charters: [
            'https://www.w3.org/International/groups/wg/charter-2019-2021.html',
        ],
        thisVersion:
            'https://www.w3.org/TR/2021/NOTE-predefined-counter-styles-20211104/',
        latestVersion: 'https://www.w3.org/TR/predefined-counter-styles/',
        history:
            'https://www.w3.org/standards/history/predefined-counter-styles',
        rectrack: 'Note',
        editorsDraft: 'https://w3c.github.io/predefined-counter-styles/',
        updated: false,
    },
    {
        file: '2021-stmt',
        profile: 'STMT',
        title: 'Ready-made Counter Styles',
        docDate: '2021-11-4',
        editorIDs: [3439],
        editorNames: ['Richard Ishida'],
        informative: false,
        process: 'https://www.w3.org/2023/Process-20231103/',
        delivererIDs: [32113],
        patentPolicy: 'https://www.w3.org/Consortium/Patent-Policy-20170801/',
        charters: [
            'https://www.w3.org/International/groups/wg/charter-2019-2021.html',
        ],
        thisVersion:
            'https://www.w3.org/TR/2021/STMT-predefined-counter-styles-20211104/',
        latestVersion: 'https://www.w3.org/TR/predefined-counter-styles/',
        history:
            'https://www.w3.org/standards/history/predefined-counter-styles',
        rectrack: 'Note',
        editorsDraft: 'https://w3c.github.io/predefined-counter-styles/',
        updated: false,
    },
    {
        file: '2021-dry',
        profile: 'DRY',
        title: 'Ready-made Counter Styles',
        docDate: '2021-11-4',
        editorIDs: [3439],
        editorNames: ['Richard Ishida'],
        informative: false,
        process: 'https://www.w3.org/2023/Process-20231103/',
        delivererIDs: [32113],
        charters: [
            'https://www.w3.org/International/groups/wg/charter-2019-2021.html',
        ],
        patentPolicy: 'https://www.w3.org/Consortium/Patent-Policy-20170801/',
        thisVersion:
            'https://www.w3.org/TR/2021/DRY-predefined-counter-styles-20211104/',
        latestVersion: 'https://www.w3.org/TR/predefined-counter-styles/',
        history:
            'https://www.w3.org/standards/history/predefined-counter-styles',
        rectrack: 'Registry',
        editorsDraft: 'https://w3c.github.io/predefined-counter-styles/',
        updated: false,
    },
    {
        file: '2021-cry',
        profile: 'CRY',
        title: 'Ready-made Counter Styles',
        docDate: '2021-11-4',
        editorIDs: [3439],
        editorNames: ['Richard Ishida'],
        informative: false,
        process: 'https://www.w3.org/2023/Process-20231103/',
        delivererIDs: [32113],
        patentPolicy: 'https://www.w3.org/Consortium/Patent-Policy-20170801/',
        charters: [
            'https://www.w3.org/International/groups/wg/charter-2019-2021.html',
        ],
        thisVersion:
            'https://www.w3.org/TR/2021/CRY-predefined-counter-styles-20211104/',
        latestVersion: 'https://www.w3.org/TR/predefined-counter-styles/',
        history:
            'https://www.w3.org/standards/history/predefined-counter-styles',
        rectrack: 'Registry',
        editorsDraft: 'https://w3c.github.io/predefined-counter-styles/',
        updated: false,
    },
    {
        file: '2021-cryd',
        profile: 'CRYD',
        title: 'Ready-made Counter Styles',
        docDate: '2021-11-4',
        editorIDs: [3439],
        editorNames: ['Richard Ishida'],
        informative: false,
        process: 'https://www.w3.org/2023/Process-20231103/',
        delivererIDs: [32113],
        charters: [
            'https://www.w3.org/International/groups/wg/charter-2019-2021.html',
        ],
        patentPolicy: 'https://www.w3.org/Consortium/Patent-Policy-20170801/',
        thisVersion:
            'https://www.w3.org/TR/2021/CRYD-predefined-counter-styles-20211104/',
        latestVersion: 'https://www.w3.org/TR/predefined-counter-styles/',
        history:
            'https://www.w3.org/standards/history/predefined-counter-styles',
        rectrack: 'Registry',
        editorsDraft: 'https://w3c.github.io/predefined-counter-styles/',
        updated: false,
    },
    {
        file: '2021-ry',
        profile: 'RY',
        title: 'Ready-made Counter Styles',
        docDate: '2021-11-4',
        editorIDs: [3439],
        editorNames: ['Richard Ishida'],
        informative: false,
        process: 'https://www.w3.org/2023/Process-20231103/',
        delivererIDs: [32113],
        charters: [
            'https://www.w3.org/International/groups/wg/charter-2019-2021.html',
        ],
        patentPolicy: 'https://www.w3.org/Consortium/Patent-Policy-20170801/',
        thisVersion:
            'https://www.w3.org/TR/2021/RY-predefined-counter-styles-20211104/',
        latestVersion: 'https://www.w3.org/TR/predefined-counter-styles/',
        history:
            'https://www.w3.org/standards/history/predefined-counter-styles',
        rectrack: 'Registry',
        editorsDraft: 'https://w3c.github.io/predefined-counter-styles/',
        updated: false,
    },
];

==> specberus-11.4.1.tgz: package/test/samples.js <==
export const samples = [
    {
        file: '2021-fpwd',
        profile: 'FPWD',
        title: 'Foo Time',
        docDate: '2021-11-4',
        editorIDs: [3439],
        editorNames: ['George Herald'],
        informative: false,
        process: 'https://www.w3.org/policies/process/20231103/',
        delivererIDs: [45211],
        patentPolicy: 'https://www.w3.org/policies/patent-policy/20200915/',
        charters: ['https://www.w3.org/2021/02/webperf.html'],
        thisVersion: 'https://www.w3.org/TR/2021/WD-hr-foo-time-2-20211104/',
        latestVersion: 'https://www.w3.org/TR/hr-foo-time-2/',
        history: 'https://www.w3.org/standards/history/hr-foo-time-2',
        rectrack: 'Recommendation',
        editorsDraft: 'https://w3c.github.io/hr-foo-time/',
        updated: false,
    },
    {
        file: '2021-wd',
        profile: 'WD',
        title: 'Foo Time',
        docDate: '2021-11-4',
        editorIDs: [3439],
        editorNames: ['George Herald'],
        informative: false,
        process: 'https://www.w3.org/policies/process/20231103/',
        delivererIDs: [45211],
        thisVersion: 'https://www.w3.org/TR/2021/WD-hr-time-2-20211104/',
        latestVersion: 'https://www.w3.org/TR/hr-time-2/',
        history: 'https://www.w3.org/standards/history/hr-time-2',
        rectrack: 'Recommendation',
        editorsDraft: 'https://w3c.github.io/hr-time/',
        updated: false,
        charters: ['https://www.w3.org/2021/02/webperf.html'],
        patentPolicy: 'https://www.w3.org/policies/patent-policy/20200915/',
    },
    {
        file: '2021-wd-shortname-change',
        profile: 'WD',
        rectrack: 'Recommendation',
        title: 'Foo Time',
        docDate: '2021-11-4',
        editorIDs: [3439],
        editorNames: ['George Herald'],
        informative: false,
        process: 'https://www.w3.org/policies/process/20231103/',
        delivererIDs: [45211],
        thisVersion: 'https://www.w3.org/TR/2021/WD-new-name-3-20211104/',
        latestVersion: 'https://www.w3.org/TR/new-name-3/',
        history: 'https://www.w3.org/standards/history/new-name-3',
        editorsDraft: 'https://w3c.github.io/foo-time/',
        sameWorkAs: 'https://www.w3.org/TR/hr-time-3/',
        updated: false,
        patentPolicy: 'https://www.w3.org/policies/patent-policy/20200915/',
        charters: ['https://www.w3.org/2021/02/webperf.html'],
    },
    {
        file: '2021-cr',
        profile: 'CR',
        implementationFeedbackDue: '2022-6-6',
        implementationReport: 'https://wpt.fyi/hr-time/',
        title: 'High Resolution Time',
        docDate: '2021-11-4',
        editorIDs: [3439],
        editorNames: ['George Herald'],
        informative: false,
        process: 'https://www.w3.org/policies/process/20231103/',
        delivererIDs: [45211],
        patentPolicy: 'https://www.w3.org/policies/patent-policy/20200915/',
        charters: ['https://www.w3.org/2021/02/webperf.html'],
        thisVersion: 'https://www.w3.org/TR/2021/CR-hr-time-2-20211104/',
        latestVersion: 'https://www.w3.org/TR/hr-time-2/',
        history: 'https://www.w3.org/standards/history/hr-time-2',
        rectrack: 'Recommendation',
        editorsDraft: 'https://w3c.github.io/hr-time/',
        updated: false,
    },
    {
        file: '2021-crd',
        profile: 'CRD',
        implementationReport: 'https://wpt.fyi/hr-time/',
        title: 'High Resolution Time',
        docDate: '2021-11-4',
        editorIDs: [3439],
        editorNames: ['George Herald'],
        informative: false,
        process: 'https://www.w3.org/policies/process/20231103/',
        delivererIDs: [45211],
        charters: ['https://www.w3.org/2021/02/webperf.html'],
        patentPolicy: 'https://www.w3.org/policies/patent-policy/20200915/',
        thisVersion: 'https://www.w3.org/TR/2021/CRD-hr-time-2-20211104/',
        latestVersion: 'https://www.w3.org/TR/hr-time-2/',
        history: 'https://www.w3.org/standards/history/hr-time-2',
        rectrack: 'Recommendation',
        editorsDraft: 'https://w3c.github.io/hr-time/',
        updated: false,
    },
    {
        file: '2021-pr',
        profile: 'PR',
        prReviewsDue: '2022-7-13',
        implementationReport: 'https://wpt.fyi/hr-time/',
        title: 'High Resolution Time',
        docDate: '2021-11-4',
        editorIDs: [3439],
        editorNames: ['George Herald'],
        informative: false,
        process: 'https://www.w3.org/policies/process/20231103/',
        delivererIDs: [45211],
        charters: ['https://www.w3.org/2021/02/webperf.html'],
        patentPolicy: 'https://www.w3.org/policies/patent-policy/20200915/',
        thisVersion: 'https://www.w3.org/TR/2021/PR-hr-time-2-20211104/',
        latestVersion: 'https://www.w3.org/TR/hr-time-2/',
        history: 'https://www.w3.org/standards/history/hr-time-2',
        rectrack: 'Recommendation',
        editorsDraft: 'https://w3c.github.io/hr-time/',
        updated: false,
    },
    {
        file: '2021-rec',
        profile: 'REC',
        title: 'CSS Color Module Level 3',
        docDate: '2022-1-18',
        editorIDs: [1464, 1438, 15393],
        editorNames: [
            'Tantek Çelik\n          (Mozilla Corporation,\n     and before at Microsoft\n     Corporation) <tantek@cs.stanford.edu>',
            'Chris Lilley',
            'L.\n      David Baron',
        ],
        informative: false,
        process: 'https://www.w3.org/policies/process/20231103/',
        delivererIDs: [32061],
        charters: ['https://www.w3.org/2020/12/css-wg-charter.html'],
        patentPolicy: 'https://www.w3.org/policies/patent-policy/20200915/',
        thisVersion: 'https://www.w3.org/TR/2022/REC-css-color-3-20220118/',
        latestVersion: 'https://www.w3.org/TR/css-color-3/',
        history: 'https://www.w3.org/standards/history/css-color-3',
        rectrack: 'Recommendation',
        editorsDraft: 'https://drafts.csswg.org/css-color-3/',
        updated: false,
    },
    {
        file: '2021-dnote',
        profile: 'DNOTE',
        title: 'Ready-made Counter Styles',
        docDate: '2021-11-4',
        editorIDs: [3439],
        editorNames: ['Richard Ishida'],
        informative: false,
        process: 'https://www.w3.org/policies/process/20231103/',
        delivererIDs: [32113],
        patentPolicy: 'https://www.w3.org/Consortium/Patent-Policy-20170801/',
        charters: [
            'https://www.w3.org/International/groups/wg/charter-2019-2021.html',
        ],
        thisVersion:
            'https://www.w3.org/TR/2021/DNOTE-predefined-counter-styles-20211104/',
        latestVersion: 'https://www.w3.org/TR/predefined-counter-styles/',
        history:
            'https://www.w3.org/standards/history/predefined-counter-styles',
        rectrack: 'Note',
        editorsDraft: 'https://w3c.github.io/predefined-counter-styles/',
        updated: false,
    },
    {
        file: '2021-note',
        profile: 'NOTE',
        title: 'Ready-made Counter Styles',
        docDate: '2021-11-4',
        editorIDs: [3439],
        editorNames: ['Richard Ishida'],
        informative: true,
        process: 'https://www.w3.org/policies/process/20231103/',
        delivererIDs: [32113],
        patentPolicy: 'https://www.w3.org/Consortium/Patent-Policy-20170801/',
        charters: [
            'https://www.w3.org/International/groups/wg/charter-2019-2021.html',
        ],
        thisVersion:
            'https://www.w3.org/TR/2021/NOTE-predefined-counter-styles-20211104/',
        latestVersion: 'https://www.w3.org/TR/predefined-counter-styles/',
        history:
            'https://www.w3.org/standards/history/predefined-counter-styles',
        rectrack: 'Note',
        editorsDraft: 'https://w3c.github.io/predefined-counter-styles/',
        updated: false,
    },
    {
        file: '2021-stmt',
        profile: 'STMT',
        title: 'Ready-made Counter Styles',
        docDate: '2021-11-4',
        editorIDs: [3439],
        editorNames: ['Richard Ishida'],
        informative: false,
        process: 'https://www.w3.org/policies/process/20231103/',
        delivererIDs: [32113],
        patentPolicy: 'https://www.w3.org/Consortium/Patent-Policy-20170801/',
        charters: [
            'https://www.w3.org/International/groups/wg/charter-2019-2021.html',
        ],
        thisVersion:
            'https://www.w3.org/TR/2021/STMT-predefined-counter-styles-20211104/',
        latestVersion: 'https://www.w3.org/TR/predefined-counter-styles/',
        history:
            'https://www.w3.org/standards/history/predefined-counter-styles',
        rectrack: 'Note',
        editorsDraft: 'https://w3c.github.io/predefined-counter-styles/',
        updated: false,
    },
    {
        file: '2021-dry',
        profile: 'DRY',
        title: 'Ready-made Counter Styles',
        docDate: '2021-11-4',
        editorIDs: [3439],
        editorNames: ['Richard Ishida'],
        informative: false,
        process: 'https://www.w3.org/policies/process/20231103/',
        delivererIDs: [32113],
        charters: [
            'https://www.w3.org/International/groups/wg/charter-2019-2021.html',
        ],
        patentPolicy: 'https://www.w3.org/Consortium/Patent-Policy-20170801/',
        thisVersion:
            'https://www.w3.org/TR/2021/DRY-predefined-counter-styles-20211104/',
        latestVersion: 'https://www.w3.org/TR/predefined-counter-styles/',
        history:
            'https://www.w3.org/standards/history/predefined-counter-styles',
        rectrack: 'Registry',
        editorsDraft: 'https://w3c.github.io/predefined-counter-styles/',
        updated: false,
    },
    {
        file: '2021-cry',
        profile: 'CRY',
        title: 'Ready-made Counter Styles',
        docDate: '2021-11-4',
        editorIDs: [3439],
        editorNames: ['Richard Ishida'],
        informative: false,
        process: 'https://www.w3.org/policies/process/20231103/',
        delivererIDs: [32113],
        patentPolicy: 'https://www.w3.org/Consortium/Patent-Policy-20170801/',
        charters: [
            'https://www.w3.org/International/groups/wg/charter-2019-2021.html',
        ],
        thisVersion:
            'https://www.w3.org/TR/2021/CRY-predefined-counter-styles-20211104/',
        latestVersion: 'https://www.w3.org/TR/predefined-counter-styles/',
        history:
            'https://www.w3.org/standards/history/predefined-counter-styles',
        rectrack: 'Registry',
        editorsDraft: 'https://w3c.github.io/predefined-counter-styles/',
        updated: false,
    },
    {
        file: '2021-cryd',
        profile: 'CRYD',
        title: 'Ready-made Counter Styles',
        docDate: '2021-11-4',
        editorIDs: [3439],
        editorNames: ['Richard Ishida'],
        informative: false,
        process: 'https://www.w3.org/policies/process/20231103/',
        delivererIDs: [32113],
        charters: [
            'https://www.w3.org/International/groups/wg/charter-2019-2021.html',
        ],
        patentPolicy: 'https://www.w3.org/Consortium/Patent-Policy-20170801/',
        thisVersion:
            'https://www.w3.org/TR/2021/CRYD-predefined-counter-styles-20211104/',
        latestVersion: 'https://www.w3.org/TR/predefined-counter-styles/',
        history:
            'https://www.w3.org/standards/history/predefined-counter-styles',
        rectrack: 'Registry',
        editorsDraft: 'https://w3c.github.io/predefined-counter-styles/',
        updated: false,
    },
    {
        file: '2021-ry',
        profile: 'RY',
        title: 'Ready-made Counter Styles',
        docDate: '2021-11-4',
        editorIDs: [3439],
        editorNames: ['Richard Ishida'],
        informative: false,
        process: 'https://www.w3.org/policies/process/20231103/',
        delivererIDs: [32113],
        charters: [
            'https://www.w3.org/International/groups/wg/charter-2019-2021.html',
        ],
        patentPolicy: 'https://www.w3.org/Consortium/Patent-Policy-20170801/',
        thisVersion:
            'https://www.w3.org/TR/2021/RY-predefined-counter-styles-20211104/',
        latestVersion: 'https://www.w3.org/TR/predefined-counter-styles/',
        history:
            'https://www.w3.org/standards/history/predefined-counter-styles',
        rectrack: 'Registry',
        editorsDraft: 'https://w3c.github.io/predefined-counter-styles/',
        updated: false,
    },
];
